@@ -320,7 +320,7 @@ idData<-idData[!(idData$animal.id %in% outlierIds),]
       spdf <-
         SpatialPointsDataFrame(crds[!outliers,],
                                allLocData[!outliers,],
-                               proj4string = CRS("+proj=longlat +ellps=WGS84 +datum=WGS84"))
+                               proj4string = CRS("+proj=longlat +datum=WGS84"))
       m <- new(
         "MoveStack",
         spdf,
